"""
Classifies: CHEBI:26254 prenylnaphthoquinone
"""
from rdkit import Chem
from rdkit.Chem import AllChem

def is_prenylnaphthoquinone(smiles: str):
    """
    Determines if a molecule is a prenylnaphthoquinone (a naphthoquinone substituted at position 2 by a prenyl or polyprenyl group, including compounds functionalized on the prenyl/polyprenyl chain).

    Args:
        smiles (str): SMILES string of the molecule

    Returns:
        bool: True if the molecule is a prenylnaphthoquinone, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return False, "Invalid SMILES string"

    # Find the naphthoquinone core
    naphthoquinone_smarts = "[$(O=C1C=CC2=C(C=CC=C2)C=C1[O,$(O=C)])]"
    matches = mol.GetSubstructMatches(Chem.MolFromSmarts(naphthoquinone_smarts))

    if not matches:
        return False, "No naphthoquinone core found"

    # Find the prenyl/polyprenyl group at position 2
    prenyl_smarts = "[$(CC=C(C)CC=C),$(CC=C(C)CCC=C),$(CC=C(C)CCCC=C)]"
    prenyl_pattern = Chem.MolFromSmarts(prenyl_smarts)

    # Find the atoms in the naphthoquinone core
    naphthoquinone_atoms = set([atom.GetIdx() for match in matches for atom in mol.GetAtoms()[match:match+10]])

    # Find atoms in the prenyl/polyprenyl group
    prenyl_atoms = set()
    for match in mol.GetSubstructMatches(prenyl_pattern):
        prenyl_atoms.update(match)

    # Check if the prenyl/polyprenyl group is attached to position 2
    if any(atom.GetIdx() in naphthoquinone_atoms and any(nbr.GetIdx() in prenyl_atoms for nbr in atom.GetNeighbors()) for atom in mol.GetAtoms()):
        return True, "Prenylnaphthoquinone found"
    else:
        return False, "No prenyl/polyprenyl group found at position 2 of the naphthoquinone core"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:26254',
                          'name': 'prenylnaphthoquinone',
                          'definition': 'Any napthoquinone that is substituted '
                                        'at position 2 by a prenyl or '
                                        'polyprenyl group. The term also '
                                        'includes compounds that are '
                                        'functionalised on the prenyl or '
                                        'polyprenyl chain (e.g. by a hydroxy '
                                        'group).',
                          'parents': ['CHEBI:25481', 'CHEBI:26255']},
    'config': {   'llm_model_name': 'claude-3-sonnet',
                  'f1_threshold': 0.0,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': None,
    'attempt': 0,
    'success': True,
    'best': True,
    'error': '',
    'stdout': None,
    'num_true_positives': 0,
    'num_false_positives': 0,
    'num_true_negatives': 183916,
    'num_false_negatives': 1,
    'num_negatives': None,
    'precision': 0.0,
    'recall': 0.0,
    'f1': 0,
    'accuracy': 0.9999945627647254}


"""
Classifies: CHEBI:24899 isoleucine derivative
"""
from rdkit import Chem
from rdkit.Chem import AllChem
from rdkit.Chem import Descriptors
from rdkit.Chem import rdMolDescriptors

def is_isoleucine_derivative(smiles: str):
    """
    Determines if a molecule is an isoleucine derivative.
    
    Args:
        smiles (str): SMILES string of the molecule
        
    Returns:
        bool: True if molecule is an isoleucine derivative, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return None, "Invalid SMILES string"

    # Define isoleucine substructure pattern
    isoleucine_pattern = Chem.MolFromSmarts('[CH3][CH2][CH]([CH3])[CH]([NH2,NH,N])[C](=O)[O,N]')
    
    # Define patterns that would indicate derivatives
    modified_patterns = [
        # N-substituted/acylated isoleucine
        Chem.MolFromSmarts('[CH3][CH2][CH]([CH3])[CH]([NX3])C(=O)[O,N]'),
        # O-substituted isoleucine
        Chem.MolFromSmarts('[CH3][CH2][CH]([CH3])[CH]([NX3])C(=O)[OX2][!H]'),
    ]

    # Check if molecule contains isoleucine core structure
    has_isoleucine_core = False
    if isoleucine_pattern is not None and mol.HasSubstructMatch(isoleucine_pattern):
        has_isoleucine_core = True
    else:
        for pattern in modified_patterns:
            if pattern is not None and mol.HasSubstructMatch(pattern):
                has_isoleucine_core = True
                break

    if not has_isoleucine_core:
        return False, "No isoleucine core structure found"

    # Analyze modifications
    modifications = []
    
    # Check for N-substitution/acylation
    n_subst_pattern = Chem.MolFromSmarts('[CH3][CH2][CH]([CH3])[CH]([NX3][!H])[C](=O)')
    if n_subst_pattern and mol.HasSubstructMatch(n_subst_pattern):
        if mol.HasSubstructMatch(Chem.MolFromSmarts('[CH3][CH2][CH]([CH3])[CH]([NH]C(=O))')):
            modifications.append("N-acylated")
        else:
            modifications.append("N-substituted")
        
    # Check for O-substitution
    o_subst_pattern = Chem.MolFromSmarts('[CH3][CH2][CH]([CH3])[CH]([NX3])C(=O)[OX2][!H]')
    if o_subst_pattern and mol.HasSubstructMatch(o_subst_pattern):
        modifications.append("O-substituted")

    # Count peptide bonds
    peptide_pattern = Chem.MolFromSmarts('[NX3][CX3](=O)[CX4][NX3][CX3](=O)[CX4][NX3][CX3](=O)')
    peptide_matches = len(mol.GetSubstructMatches(peptide_pattern)) if peptide_pattern else 0

    # Count isoleucine fragments
    ile_fragment_count = len(mol.GetSubstructMatches(isoleucine_pattern)) if isoleucine_pattern else 0

    # If there are multiple peptide bonds and multiple isoleucine fragments, it's likely a peptide
    if peptide_matches >= 1 and ile_fragment_count >= 2:
        return False, "Appears to be a peptide containing isoleucine rather than an isoleucine derivative"

    if modifications:
        return True, f"Isoleucine derivative with modifications: {', '.join(modifications)}"
    else:
        return True, "Unmodified isoleucine derivative"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:24899',
                          'name': 'isoleucine derivative',
                          'definition': 'An amino acid derivative resulting '
                                        'from reaction of isoleucine at the '
                                        'amino group or the carboxy group, or '
                                        'from the replacement of any hydrogen '
                                        'of isoleucine by a heteroatom. The '
                                        'definition normally excludes peptides '
                                        'containing isoleucine residues.',
                          'parents': ['CHEBI:83821']},
    'config': {   'llm_model_name': 'lbl/claude-sonnet',
                  'f1_threshold': 0.8,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': '\n'
               'Attempt failed: F1 score of 0.07207207207207209 is too low.\n'
               'True positives: '
               "[('O=C(N[C@H](C(=O)OC[C@@H](NC(=O)C1=CC=CC=C1)C(C)C)[C@@H](CC)C)C2=CC=CC=C2', "
               "'Isoleucine derivative with modifications: O-substituted, "
               "N-acylated'), "
               "('O=C(OC)[C@H]1N(C(=O)[C@@H](N(C(=O)[C@H]2N(C(=O)[C@@H](NC(=O)[C@H](N(C(=O)[C@@H](NC(=O)[C@@H](N(C(=O)CCCCCCCCNC(=O)CCCC3=CC=C(O)C=C3)C)CC(C)C)[C@H](CC)C)C)C(C)C)CCC(=O)N)CCC2)C)CC4=CC=CC=C4)CCC1', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('ClC1=C(O)C(Cl)=CC(=C1)C[C@H](O)C(=O)N[C@@H](C(=O)N2[C@@H]3[C@@H](CC[C@H](C3)O)C[C@H]2C(=O)NCCCCN=C(N)N)[C@H](CC)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(O)[C@H](NC(=O)C)[C@@H](CC)C', 'Isoleucine derivative "
               "with modifications: N-acylated')]\n"
               'False positives: '
               "[('O=C1O[C@@H]([C@@H](NC(=O)[C@H](NC(=O)[C@H](NC(=O)CC(O)CCCCCCC)CC(C)C)CC(=O)O)C(=O)N[C@@H](C(=O)N[C@@H](C(=O)N[C@@H](C(=O)N[C@H](C(N[C@@H](C(N[C@H](C(N[C@H](C(N[C@H]1CC(=O)O)=O)[C@H](CC)C)=O)[C@H](CC)C)=O)CO)=O)CC(C)C)CO)CC(C)C)CC(C)C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N[C@@H](CO)C(O)=O)[C@@H](NC(=O)[C@@H](N)CC(C)C)[C@H](CC)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O[C@@H]([C@H](NC(=O)[C@@H](N)CC1=CC=CC=C1)C(=O)N[C@@H]([C@H](CC)C)C(O)=O)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1N[C@H](C(=O)N([C@H](C(=O)N([C@H](C(=O)N([C@H](C(=O)O[C@@H](C(C)C)C(N2[C@H](C(N3[C@H](C(N[C@H](C(O[C@@H](C1(C)C)CCCCC)=O)C(C)C)=O)CCC3)=O)CCC2)=O)C(C)C)C)C(C)C)C)C)C)[C@H](CC)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1OC(C(=O)N[C@H](C(=O)N[C@H](C(=O)O)[C@H](CC)C)C(C)C)C1C(C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1O[C@@H]([C@H](NC(=O)[C@@H](NC(=O)[C@H](NC(=O)[C@@H](NC(=O)CCCCCCCCC)CC=2C3=C(C=CC=C3)NC2)CCC(=O)O)[C@@H](O)C(=O)N)C(=O)N(CC(=O)N[C@H](C(=O)N[C@H](C(=O)N[C@H](CCCCN)C(N[C@H](C(NCC(N[C@@H](C(N[C@H](C(N[C@H]1[C@H](CC)C)=O)CCC(=O)O)=O)CC(=O)N)=O)=O)[C@@H](OC)C(=O)O)=O)CC(=O)O)C)C)C', "
               "'Isoleucine derivative with modifications: O-substituted, "
               "N-acylated'), "
               "('O=C1O[C@H](C(=O)N2[C@H](C(=O)N[C@H](C(=O)O[C@@H]([C@@H](C(N[C@H](C(N([C@H]1C(C)C)C)=O)C(C)C)=O)C)CCCCC)[C@H](CC)C)CCC2)CC3=CC=CC=C3', "
               "'Isoleucine derivative with modifications: O-substituted, "
               "N-acylated'), "
               "('S(CCC(N)C(=O)NC(C(=O)NC(C(=O)NC(C(=O)NC(C(=O)NC(C(=O)NC(C(=O)NC(C(=O)NC(C(=O)N1C(C(=O)NC(C(=O)N2C(C(=O)NCC(=O)N3C(C(=O)NC(C(=O)NC(C(=O)NC(C(=O)NC(C(=O)NC(C(=O)O)C(CC)C)CCC(=O)O)C)C)C)CCC3)CCC2)C(CC)C)CCC1)C)CC(C)C)CCC(=O)O)CCCNC(=N)N)CC4=CC=C(O)C=C4)CC(C)C)CC(=O)N)CC(=O)N)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('SC[C@H](N)C(=O)N[C@@H]([C@H](CC)C)C(=O)N[C@@H](CCC(=O)N)C(O)=O', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1NC(C(=O)NCCCCC(C(NC1C(CC)C)=O)NC(=O)NC(C(=O)O)C(C)C)CCC2=CC=CC=C2', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N1C(C(=O)NC(C(=O)NC(C(=O)NC(C(=O)NC(C(=O)NC(C(=O)NC(CO)CC2=CC=CC=C2)CCC(=O)N)CCC(=O)N)(C)C)(C)C)C(C)C)CCC1)C(NC(=O)C(NC(=O)CNC(=O)C(NC(=O)C(NC(=O)C(NC(=O)C(NC(=O)C(NC(=O)C(NC(=O)C(NC(=O)C(NC(=O)C(NC(=O)C(NC(=O)C)(C)C)C)(C)C)C)(C)C)C)CCC(=O)N)(C)C)C(CC)C)(C)C)(C)C)(C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1N([C@H](C(=O)NCCC(=O)O[C@H](CC(CO)C)C(N2[C@H](C(N[C@H](C(N[C@H]1C(C)C)=O)C(CC)C)=O)CCC2)=O)C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1OC([C@H](NC(=O)C(NC(=O)C(NC(=O)[C@H](NC(=O)C(NC(=O)C(NC(=O)[C@H](NC(=O)[C@@H](NC(=O)C(NC(=O)C(NC(=O)[C@H](NC(=O)C(NC(=O)C(O)CO)CC(C)C)C)CC(C)C)CC(C)C)C(CC)C)CCCNC(=N)N)CC(C)C)CC(C)C)C(C)C)CCCCN)CC(C)C)C(=O)NC(C(=O)N[C@@H](C(NC(C(NC1CCCCN)=O)CCCCN)=O)C)CC(C)C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('ClC1=CC=2NC(Cl)=C(C2C=C1)C[C@H]3NC(=O)[C@H](NC(=O)[C@H](NC(=O)[C@H](CO)NC([C@H](NC([C@@H](NC3=O)[C@@H](CC)C)=O)CCC(=O)O)=O)C(C)C)CC=4C5=C(C=CC=C5)NC4', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N[C@@H]([C@H](CC)C)C(=O)N[C@@H](CCCCN)C(O)=O)[C@H]1NCCC1', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('CCCCCCCCCCCCCCCCCCCC(=O)N[C@H](Cc1ccccc1)C(=O)N(C)[C@@H](C(C)C)C(=O)N[C@@H](C(C)CC)C(=O)N[C@@H](Cc1ccccc1)C(=O)N[C@@H](C)C(=O)OC', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N[C@@H](CCCN=C(N)N)C(O)=O)[C@@H](NC(=O)CN)[C@H](CC)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('CC[C@H](C)[C@@H](C(=O)N1CCC[C@H]1C(=O)N[C@@H]([C@@H](C)CC)C(=O)O)N', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1O[C@@H]([C@H](NC(=O)CC(O)CCCCCCCCCCCCN=C(N)N)C(=O)N[C@@H](C(=O)N[C@@H]([C@H](CC)C)C(N[C@@H](C(N[C@@H](C(N[C@@H]1C)=O)CCC(=O)N)=O)[C@H](O)C)=O)C(C)C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1N(C(C(=O)NC(C(=O)NCCCCC(C(NC(C(NC1CCC2=CC=CC=C2)=O)C(C)C)=O)NC(=O)NC(C(=O)O)C(CC)C)CC3=CC=CC=C3)C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1N([C@H](C(=O)N([C@H](C(=O)N([C@H](C(=O)N2[C@H](C(=O)N([C@H](C(=O)N3[C@@H](CCC3)C(O[C@@H](CCC[C@H]([C@H](C(O[C@@H]([C@H](CC=C(C(=C1)OC)C)C)C)=O)C)O)CC)=O)C(C)C)C)CCC2)COC)C)C(C)C)C)[C@H](CC)C)C', "
               "'Isoleucine derivative with modifications: N-substituted'), "
               "('O=C1NC(C(C)C)C(=O)NC(C(C)C)C(=O)N(C(C(=O)NC(CC(C)C)C(=O)N(C(C(=O)N(C(C(=O)NC1C(CC)C)CC=2C=COC2)C)C)C)CC=3C=COC3)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('SC[C@H](NC(=O)CN)C(=O)N[C@@H]([C@H](CC)C)C(O)=O', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('CC[C@H](C)[C@H](NC(=O)[C@@H](NC(=O)[C@H](C)NC(=O)[C@H](CCCCNC(=O)c1cc(ccc1C(F)(F)F)C(F)(F)F)NC(=O)[C@H](CC(O)=O)NC(C)=O)[C@@H](C)O)C(=O)NCC(=O)N[C@@H](Cc1ccccc1)C(=O)N[C@@H](CCC(O)=O)C(=O)N[C@@H](C(C)C)C(=O)N[C@@H](CCC(N)=O)C(=O)N[C@@H](CCC(O)=O)C(=O)N[C@@H](CCC(O)=O)C(O)=O', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('S1SC(N)C(=O)N[C@H](C(=O)N[C@@]([C@@H](CC)C)(C(=O)N[C@H](C(=O)NC(C(=O)N[C@@H](C(=O)N2[C@H](CCC2)C(=O)N[C@H](CC(C)C)C(O)=O)C1)CC(=O)N)CCC(=O)N)[H])CC3=CC=C(O)C=C3', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(NC(C(=O)NC(CNCCO)C)(C)C)C(NC(=O)[C@@H](NC(=O)[C@@H](NC(=O)C(NC(=O)[C@@H](NC(=O)[C@@H](NC(=O)[C@H]1N(C(=O)C(CCCCCC)C)CCC1)CC(CC(O)CC(=O)CC)C)C)(C)C)[C@H](CC)C)[C@H](CC)C)(C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1N([C@H](C(=O)NCCC(=O)O[C@H](CC(O)CO)C(N2C(C(N[C@H](C(N([C@H]1C(C)C)C)=O)[C@H](CC)C)=O)CCC2)=O)C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N[C@@H]([C@H](O)C)C(O)=O)[C@@H](NC(=O)[C@@H](N)CC(C)C)[C@H](CC)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1N(C(C(=O)NC(C(=O)NCCCCC(C(NC(C(NC1CC=2C3=C(C=CC=C3)NC2)=O)C(CC)C)=O)NC(=O)NC(C(=O)O)C(C)C)CC4=CC=CC=C4)C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N[C@@H]([C@H](CC)C)C(O)=O)[C@@H](NC(=O)[C@@H](N)CC(C)C)CC=1NC=NC1', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('CC[C@H](C)[C@@H](C(=O)N[C@@]1(CCCC=CCCC[C@](NC(=O)[C@@H](NC(=O)[C@@H](NC(=O)[C@@H](NC1=O)CC(C)C)CS)CCCNC(=N)N)(C)C(=O)N[C@@H](CC2=CNC=N2)C(=O)N[C@@H](CC3=CNC=N3)C(=O)N[C@@H](CO)C(=O)N[C@@H]([C@@H](C)O)C(=O)N)C)NC(=O)[C@H](CCCNC(=N)N)NC(=O)[C@H](CCCNC(=N)N)NC(=O)[C@H](CCCNC(=N)N)NC(=O)[C@H](CC(C)C)NC(=O)[C@H](CCCNC(=N)N)NC(=O)[C@H](CCC(=O)O)NC(=O)[C@H](CC4=CNC5=CC=CC=C54)NC(=O)CCNC(=O)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('BrC1=C(OC)C=CC(=C1)C[C@@H]2N(C(=O)[C@@H](N3C(=O)[C@@H](NC(=O)[C@H](CCCN=C(N)N)NC([C@H]([C@H](OC([C@@H](NC2=O)C(C)C)=O)C)NC(=O)[C@@H](NC(=O)CCC)CCS(=O)C)=O)CC[C@H]3O)[C@H](CC)C)C', "
               "'Isoleucine derivative with modifications: N-substituted'), "
               "('S(CC[C@H](NC(=O)[C@@H](NC(=O)[C@@H](N)[C@H](O)C)[C@H](CC)C)C(O)=O)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('ClC1=C(O)C=CC(=C1)C[C@@H]2N(C(=O)[C@@H](N3C(=O)[C@@H](NC(=O)[C@H](CCCN=C(N)N)NC([C@H]([C@@H](OC(C(NC2=O)C(CC)C)=O)C)NC(=O)C(NC(=O)C)CCC(=O)O)=O)CC[C@H]3O)CC4=CC=CC=C4)C', "
               "'Isoleucine derivative with modifications: O-substituted, "
               "N-acylated'), "
               "('O=C(N[C@@H]([C@H](CC)C)C(O)=O)[C@@H](NC(=O)[C@@H](N)[C@H](O)C)CC(O)=O', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('CC[C@H](C)[C@H](N(C)C)C(=O)N[C@H]1[C@@H](Oc2ccc(cc2)\\\\C=C/NC(=O)[C@H](CC(C)C)NC1=O)C(C)C', "
               "'Isoleucine derivative with modifications: N-substituted'), "
               "('O=C1OC([C@@H](NC(=O)[C@H](NC(=O)[C@@H](NC(=O)C[C@@H](O)CCCCCCCCC)CC(C)C)CCC(=O)O)C(=O)N[C@@H](C(=O)N[C@H](C(=O)N[C@@H](C(N[C@H](C(N[C@@H](C(N[C@H]1C(CC)C)=O)CO)=O)CC(C)C)=O)CO)CC(C)C)C(C)C)C', "
               "'Isoleucine derivative with modifications: O-substituted, "
               "N-acylated'), "
               "('O=C1O[C@@H](CC(=O)N[C@@H](C(=O)N[C@H](CO)C(N[C@@H](C(N[C@H](C(N[C@H]1C(CC)C)=O)CC2=CC=CC=C2)=O)[C@@H](O)C)=O)CC(C)C)CCCCCCC', "
               "'Isoleucine derivative with modifications: O-substituted, "
               "N-acylated'), "
               "('O=C(N[C@@H]([C@H](CC)C)C(O)=O)[C@@H](NC(=O)[C@@H](N)CCCN=C(N)N)CC1=CC=C(O)C=C1', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1N[C@@H](C(=O)N[C@@H](C(=O)N[C@@H](C(=O)N[C@@H](C(=O)N[C@H](CO)C(N[C@@H](C(N[C@H](C(NC(CC(O[C@@H]([C@@H]1NC(=O)C(NC(=O)[C@H](NC(=O)CC(O)CCCCCCC)CC(C)C)CC(=O)O)C)=O)C(=O)O)=O)[C@H](CC)C)=O)CC(C)C)=O)CC(C)C)CO)CC(C)C)CC(C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N[C@@H]([C@H](CC)C)C(O)=O)[C@@H](NC(=O)[C@@H](N)CC(O)=O)CC1=CC=C(O)C=C1', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1N([C@H](C(=O)N[C@@H](C(=O)N[C@@H](C)CC(O[C@@H]([C@@H](C(N[C@H]1[C@H](CC)C)=O)NC(=O)C(=NNC2=C(C(=O)OCCCCCCCCCC(C)C)C=C(O)C=C2)C)C3=CC=CC=C3)=O)CC=4C5=C(C(OC)=CC=C5)NC4)[C@@H](O)C6=CC=CC=C6)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N1C(CCC1)C(=O)NC(C(CC)C)C(O)=O)C(NC(=O)C(NC(=O)C(NC(=O)C2N(CCC2)C(=O)C(N)CC3=CC=C(O)C=C3)CC4=CC=CC=C4)C(C)C)CCC(O)=O', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1O[C@H](C(=O)N2[C@H](C(=O)N([C@H](C(=O)O[C@H]([C@H](C(N[C@H](C(N([C@H]1[C@H](CC)C)C)=O)C(C)C)=O)C)CCCC=C)C(C)C)C)CCC2)CC3=CC=CC=C3', "
               "'Isoleucine derivative with modifications: N-substituted, "
               "O-substituted'), "
               "('O=C(N1[C@H](CCC1)C(O)=O)[C@@H](NC(=O)[C@@H](N)CC(C)C)[C@H](CC)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1OC(C(CC)C)CC(=O)NC(C(=O)NC(C(=O)NC(C(=O)NC(CC2=CC=CC=C2)C(NC(C(NC(C(NC(C(NC(C(NC1CO)=O)CC(C)C)=O)C(C)C)=O)CCN)=O)CC(C)C)=O)CCN)C(CC)C)CCN', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N[C@@H](CC(O)=O)C(O)=O)[C@@H](NC(=O)CN)[C@H](CC)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('S1C(=NC(=C1)C(=O)N[C@@H](CC2=CC=C(O)C=C2)C[C@@H](C(=O)O)C)[C@H](OC(=O)C)C[C@@H](N(C(=O)[C@@H](NC(=O)[C@@H]3N(CCCC3)C)[C@H](CC)C)COC(=O)CC)C(C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('S(CC[C@H](NC(=O)[C@@H](N)CC1=CC=CC=C1)C(=O)N[C@@H]([C@H](CC)C)C(O)=O)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('CCC(C)[C@H](NC(=O)[C@H](CCC(N)=O)NC(=O)[C@H](CCCNC(N)=N)NC(=O)[C@H](CC(O)=O)NC(=O)[C@H](CCC(O)=O)NC(=O)[C@H](CC(O)=O)NC(=O)[C@H](CO)NC(=O)[C@H](Cc1ccc(O)cc1)NC(=O)[C@H](CCC(O)=O)NC(=O)[C@H](CCCNC(N)=N)NC(=O)[C@H](CC(O)=O)NC(=O)[C@@H]1CCCN1C(=O)[C@H](Cc1ccc(O)cc1)NC(=O)[C@H](CO)NC(=O)[C@@H]1CCCN1C(=O)[C@H](CO)NC(=O)[C@@H](N)CCC(N)=O)C(=O)N[C@@H](CCCCN)C(=O)N[C@@H](CCC(N)=O)C(=O)N[C@@H](CCSC)C(=O)N[C@@H](CC(C)C)C(=O)N[C@@H](Cc1c[nH]cn1)C(=O)N[C@@H](CCC(N)=O)C(=O)N[C@@H](CCC(O)=O)C(=O)N[C@@H](CS)C(=O)N1CCC[C@H]1C(=O)N[C@@H](CCCNC(N)=N)C(=O)N[C@@H](CC(C)C)C(N)=O', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1O[C@@H]([C@H](NC(=O)C[C@H](O)CC(C)C)C(=O)N[C@@H](C(=O)N[C@H](C(=O)NCC(=O)N([C@@H](C(=O)N[C@@H](CC(C)C)C(N[C@@H](C(N[C@H](C(N[C@@H](C(N[C@@H](C(N[C@H](C(N[C@H]1[C@H](O)C)=O)[C@H](CC)C)=O)CC=2C3=C(C=CC=C3)NC2)=O)CCC(=O)N)=O)CCC(=O)O)=O)CCCN=C(N)N)=O)CC4=CC=CC=C4)C)CO)CCCN=C(N)N)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1NC(C(=O)NC(C(=O)NC(C(=O)NCCCCC(C(NC1C(CC)C)=O)NC(=O)NC(C(=O)O)C(CC)C)CC2=CC=CC=C2)C)CCC3=CC=CC=C3', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('ClC(Cl)CCCCCC[C@@H](N)[C@@H](O)C(=O)N[C@H](C(=O)N([C@H](C(=O)N1[C@H](C(=O)N[C@H](C(=O)O)CC2=CC=C(O)C=C2)CCC1)CC(C)C)C)[C@H](CC)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('OC(=O)[C@@H](NC(=O)[C@@H](NC(=O)[C@@H](N)CC(O)=O)CC(=O)N)[C@H](CC)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(NC(C(=O)O)CC1=CC=C(O)C=C1)C2N(C(=O)C(N(C(=O)C(NC(=O)C(O)C(NC)CCCCCCC)CC3=CC=C(O)C=C3)C)C(CC)C)CCC2', "
               "'Isoleucine derivative with modifications: N-substituted'), "
               "('O=C(N[C@@H](CC1=CC=CC=C1)C(=O)N[C@@H]([C@H](CC)C)C(O)=O)[C@H]2NCCC2', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C/1N[C@H](C(=O)N[C@@H](C(=O)N2[C@H](C(=O)NC(C(O)C(=O)N[C@@H](C(=O)NCC(N3[C@H](C(N4[C@H](C(N[C@@H](C(N[C@H](C(N\\\\C1=C\\\\C)=O)CO)=O)[C@H](CC)C)=O)CCC4)=O)CCC3)=O)CCC(=O)N)CC(OC(=O)[C@@H](N(C(=O)C)C)CC(C)C)CC(O)CC5=CC=CC=C5)CCC2)CCC6=CC=C(OC)C=C6)[C@H](O)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('S1C(=NC(=C1)C(=O)N[C@@H](CC2=CC=CC=C2)C[C@@H](C(=O)O)C)CC(=O)[C@@H](NC(=O)[C@@H](NC(=O)[C@@H]3N(CCCC3)C)[C@H](CC)C)C(C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1O[C@@H]([C@H](NC(=O)CC[C@H](NC(=O)[C@@H](NC(=O)CCC)CC(C)C)C(=O)O)C(=O)N[C@H](C(=O)N[C@H]2CC[C@H](N([C@H](C(N([C@H](C(N[C@H]1[C@H](CC)C)=O)CC3=CC=CC=C3)C)=O)C(C)C)C2=O)O)CC4=CC=C(O)C=C4)C', "
               "'Isoleucine derivative with modifications: O-substituted, "
               "N-acylated'), "
               "('O=C(O)[C@H](NC(=O)[C@H](NC(=O)[C@H](NC(=O)[C@@H](NC(=O)[C@@H](NC(=O)[C@H](NC(=O)[C@H](NC(=O)[C@@H](NC(=O)[C@@H](NC(=O)[C@@H](NC(=O)C[C@H](O)CCCCCC(C)C)CC(=O)N)C(C)C)C(C)C)CC(=O)N)CC(=O)N)C[C@H](O)CCN)[C@@H](O)C)CO)CC=1C2=C(C=CC=C2)NC1)[C@@H](CC)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N[C@H](C(=O)N[C@H](CN)CC(C)C)[C@H](CC)C)C(NC(=O)[C@@H](NC(=O)C(NC(=O)[C@@H](NC(=O)[C@H]1N(C(=O)[C@H]2N(C(=O)CCCCCCCCC)C[C@@H](C2)O)C[C@@H](C1)O)C(C)C)(C)C)CCC(=O)N)(C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1NC(C(=O)NC(C(C(=O)OC(C(=O)NCC(=O)N(C(C(CC)C)C(NCC(N(C(C(N(C(C(NC(C(C1(C)C)=O)C)=O)CC2=CC=C(OC)C=C2)C)=O)C(C)C)C)=O)=O)C)C(CC)C)C)CC)C', "
               "'Isoleucine derivative with modifications: N-substituted'), "
               "('O=C1NC(C(=O)NCCCCC(C(NC1C(CC)C)=O)NC(=O)NC(C(=O)O)C(CC)C)CCC2=CC=CC=C2', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('CC[C@H](C)[C@H](N)C(=O)N[C@@H](CCCCN)C(=O)N[C@@H](Cc1c[nH]c2ccccc12)C(=O)N[C@@H](CCCCN)C(=O)N[C@@H](C)C(=O)N[C@@H]([C@@H](C)CC)C(=O)N[C@@H](CC(C)C)C(=O)N[C@@H](CC(O)=O)C(=O)N[C@@H](C)C(=O)N[C@@H](C(C)C)C(=O)N[C@@H](CCCCN)C(=O)N[C@@H](CCCCN)C(=O)N[C@@H](C(C)C)C(=O)N[C@@H]([C@@H](C)CC)C(N)=O', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('[H]N1[C@@H](Cc2ccc(OC)cc2)C(=O)N(C)[C@@H](C)C(=O)N(C)[C@@H]([C@@H](C)CC)C(=O)N2CCC[C@H]2C(=O)O[C@@H](C[C@@H](C)C[C@H](O)[C@H](C)C2=N[C@H](CS2)\\\\C=C(C)\\\\C1=O)C(C)(C)C', "
               "'Isoleucine derivative with modifications: N-substituted'), "
               "('O=C1N[C@H](C(=O)N[C@H](C(=O)O)CC=2NC=3C=CC=CC3C2)CCC(=O)NCCCC[C@@H]4NC(=O)C(CCCNC(=N)N)NC([C@@H]([C@H](OC(CC5C(N[C@H](C(N[C@@H]1CCC(=O)OC[C@H](NC(=O)[C@H]6N(C(=O)[C@H](CC7=CC=C(O)C=C7)NC4=O)CCC6)C(=O)N5)=O)CC=8C9=C(C=CC=C9)NC8)=O)=O)C)NC(=O)[C@@H](NC(=O)C(NC(=O)C)C(CC)C)CO)=O', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('[H]N[C@@H](CCCCN)C(N[C@H]1CSSC[C@H](NC([C@H]([C@@H](C)O)NC([C@H](C)NC([C@H]([C@@H](C)O)NC([C@@H](NC1=O)CC(N)=O)=O)=O)=O)=O)C(N[C@@H](C)C(N[C@@H]([C@@H](C)O)C(N[C@@H](CCC(N)=O)C(N[C@@H](CCCNC(N)=N)C(N[C@@H](CC(C)C)C(N[C@@H](C)C(N[C@@H](CC(N)=O)C(N[C@@H](CC2=CC=CC=C2)C(N[C@@H](CC(C)C)C(N[C@@H](C(C)C)C(N[C@@H](CC3=CNC=N3)C(N[C@@H](CO)C(N[C@@H](CO)C(N[C@@H](CC(N)=O)C(N[C@@H](CC(N)=O)C(N[C@@H](CC4=CC=CC=C4)C(NCC(N5CCC[C@H]5C(N[C@@H]([C@H](CC)C)C(N[C@@H](CC(C)C)C(N6CCC[C@H]6C(N7CCC[C@H]7C(N[C@@H]([C@@H](C)O)C(N[C@@H](CC(N)=O)C(N[C@@H](C(C)C)C(NCC(N[C@@H](CO)C(N[C@@H](CC(N)=O)C(N[C@@H]([C@@H](C)O)C(N[C@@H](CC8=CC=C(O)C=C8)C(N)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O)=O', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N[C@H](C(=O)N[C@H](C(=O)N[C@H](C(=O)O)CC(C)C)[C@H](CC)C)C)[C@](NC(=O)[C@@H](NC(=O)[C@@H](NC(=O)CNC(=O)CCCCCCC)C)CC(C)C)(CC)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1O[C@H]([C@H](NC(=O)CC[C@H](NC(=O)[C@@H](NC(=O)CCC)CC2=CC=C(O)C=C2)C(=O)OC)C(=O)N[C@H](C(=O)N[C@H]3CC[C@H](N([C@H](C(N([C@H](C(N[C@H]1[C@H](CC)C)=O)CC4=CC=CC=C4)C)=O)C(C)C)C3=O)O)CCCN=C(N)N)C', "
               "'Isoleucine derivative with modifications: O-substituted, "
               "N-acylated'), "
               "('O=C1O[C@@H]([C@H](NC(=O)CC(O)CCCCCCCCCCCCN=C(N)N)C(=O)N[C@@H](C(=O)N[C@@H]([C@H](CC)C)C(N[C@@H](C(N[C@@H](C(N[C@@H]1C)=O)CCC(=O)N)=O)[C@H](O)C)=O)[C@@H](CC)C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1O[C@@H]([C@@H](NC(=O)[C@H](NC(=O)[C@@H](NC(=O)C[C@H](O)CCCCCCCCC)CC(C)C)CCC(=O)O)C(=O)N[C@@H](C(=O)N[C@@H](C(=O)N[C@@H](C(N[C@H](C(N[C@@H](C(N[C@H]1[C@H](CC)C)=O)CO)=O)CC(C)C)=O)CO)CC(C)C)[C@H](CC)C)C', "
               "'Isoleucine derivative with modifications: O-substituted, "
               "N-acylated'), "
               "('O=C(N[C@@H](CC=1NC=NC1)C(O)=O)[C@@H](NC(=O)[C@@H](N)CC(=O)N)[C@H](CC)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('SC[C@H](NC(=O)[C@@H](NC(=O)[C@@H](N)CC=1C=2C(NC1)=CC=CC2)[C@H](CC)C)C(O)=O', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N[C@@H](CC=1C=2C(NC1)=CC=CC2)C(O)=O)[C@@H](NC(=O)[C@@H](N)CO)[C@H](CC)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N[C@@H]([C@H](CC)C)C(O)=O)[C@@H](NC(=O)[C@@H](N)CCC(O)=O)CCCCN', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('S(CC[C@@H]1NC(=O)[C@@H](NC(=O)CN(C(=O)[C@@H](NC(=O)[C@@H](NC(=O)[C@H]2N(CCC2)C(=O)[C@H]3N(CCC3)C(=O)[C@@H](NC1=O)CCC(=O)N)[C@@H](CC)C)[C@@H](O)C)C)CC(C)C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(NC(C(=O)NC(CN(CCO)C)C)(C)C)C(NC(=O)C(NC(=O)C(NC(=O)C(NC(=O)C(NC(=O)C(NC(=O)C1N(C(=O)C(CCCCCCCC)C)CCC1)CC(CC(O)CC(=O)CC)C)C)(C)C)C(C)C)C(CC)C)(C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1OC(C(NC(=O)CCCCC(CC)C)C(=O)NC(C(=O)NC(C(=O)NCC(=O)NC(C(=O)NC(C(NCC(NC(C(NC(C(NC(C(NC1CC2=CC=CC=C2)=O)CCN)=O)C(CC)C)=O)CC=3NC=4C=CC=CC4C3)=O)=O)CC(=O)O)CC(=O)N)CC(=O)O)CCN)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('ClCCCCCCC[C@@H](N)[C@@H](O)C(=O)N[C@H](C(=O)N([C@H](C(=O)N1[C@H](C(=O)N[C@H](C(=O)O)CC2=CC=C(O)C=C2)CCC1)CC(C)C)C)[C@H](CC)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('S1SC[C@H](NC(=O)[C@@H](NC(=O)[C@@H](NC([C@@H](NC([C@H](C1)NC(=O)[C@@H](NC(=O)[C@@H](NC(=O)CNC(=O)[C@H]2N(C(=O)[C@H]3NC(=O)[C@@H](NC(=O)CNC(=O)[C@@H](NC(=O)CNC(C(NC(C(NC(CNC(CC3)=O)=O)CO)=O)CCCNC(=N)N)=O)CC=4NC=5C=CC=CC5C4)CC6=CC=CC=C6)CCC2)C(C)C)CCCNC(=N)N)=O)CC(C)C)=O)[C@H](CC)C)CC=7NC=8C=CC=CC8C7)C(=O)N[C@H](C(=O)O)CC(=O)O', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N[C@@H]([C@H](CC)C)C(O)=O)[C@@H](NC(=O)[C@@H](N)[C@H](O)C)CC1=CC=C(O)C=C1', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1N([C@H](C(=O)N([C@H](C(=O)N[C@H](C(=O)N(C)[C@H](C(N([C@@H](C(N[C@@H](C(N[C@@H]1[C@H](CC)C)=O)[C@H](O)C(C)C)=O)C)C)=O)C)CC(C)C)CC(C)C)C)C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('S1C2=N[C@H](C1)C=C(C(=O)N[C@H](C(=O)N([C@H](C(=O)N(C)[C@H](C(N3[C@H](C(O[C@@H](C[C@H](C[C@@H]([C@@H]2C)O)C)C(C)(C)C)=O)CCCC3)=O)[C@H](CC)C)C)C)CC4=CC=C(OC)C=C4)C', "
               "'Isoleucine derivative with modifications: N-substituted'), "
               "('O=C1OC(CC(=O)N[C@@H](C(=O)N[C@@H](CO)C(N[C@H](C(N[C@@H](C(N[C@H]1[C@H](CC)C)=O)CC(C)C)=O)[C@H](O)C)=O)CC(C)C)CCCCCCC', "
               "'Isoleucine derivative with modifications: O-substituted, "
               "N-acylated'), "
               "('O=C(OC)[C@H]1N(C(=O)[C@H](NC(=O)[C@@H](NC(=O)[C@@H](NC(=O)C[C@H](O)[C@@H](NC(=O)[C@@H](N(C(=O)[C@@H](NC(=O)[C@@H](O)C)CC(C)C)C)CCC(=O)N)CC(C)C)[C@H](CC)C)C)CC2=CC=CC=C2)CCC1', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N[C@@H]([C@H](CC)C)C(O)=O)[C@@H](NC(=O)[C@@H](N)CC(=O)N)CC=1C=2C(NC1)=CC=CC2', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(OC)[C@H]1N(C(=O)[C@@H](NC(=O)[C@@H](NC(=O)[C@@H](NC(=O)[C@@H](N(C(=O)C(OC(=O)C(O)C(C)C)C(C)C)C)CC(=O)N)[C@H](CC)C)C)CC2=CC=CC=C2)CCC1', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1N[C@H](C(=O)N[C@H](C(=O)N[C@H](C(N[C@H]1C(CC)C)=O)CC(=O)N)CC(C)C)CC(=O)N', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('CC[C@H](C)[C@@H]1N(C)C(=O)[C@H](C)N(C)C(=O)[C@H](Cc2ccc(OC)cc2)NC(=O)\\\\C(C)=C\\\\[C@H]2CSC(=N2)[C@@H](C)[C@@H](O)C[C@H](C)C[C@H](OC(=O)[C@@H]2CCCN2C1=O)[C@@H](C)CC(C)(C)C', "
               "'Isoleucine derivative with modifications: N-substituted'), "
               "('O=C1OC2=CC=C(CC(NC(=O)C(NC(=O)C(NC(=O)CCCCCCCCCCCCCC(C)C)CCC(=O)O)CCCN)C(=O)NC(C(=O)NC(C(=O)NC(C(N3C(C(NC(C(NC(C(NC1C(CC)C)=O)CC4=CC=C(O)C=C4)=O)CCC(=O)N)=O)CCC3)=O)C(C)C)CCC(=O)O)C(O)C)C=C2', "
               "'Isoleucine derivative with modifications: O-substituted, "
               "N-acylated'), "
               "('O=C1O[C@H](C(=O)N[C@H](C(=O)N2[C@H](C(=O)N([C@H](C(=O)N(C(C(=O)N([C@H](C(=O)N([C@@H](C(=O)N[C@H](C(N([C@H](C(N[C@H](C(N3[C@H](C(N4[C@H](C(N([C@H](C(NC(C1C)CCCC#C)=O)[C@H](CC)C)C)=O)CCC4)=O)CCC3)=O)CC(C)C)=O)C(C)C)C)=O)C)C)C)CC5=CC=CC=C5)C)COC)C)C(C)C)C)CCC2)C)C(C)C', "
               "'Isoleucine derivative with modifications: N-substituted'), "
               "('O=C(N1C(CCC1)C(=O)NC2C(OC3=CC=C(C=C3)C=CNC(=O)C(NC2=O)CC4=CC=CC=C4)C5=CC=CC=C5)C(N(C)C)C(CC)C', "
               "'Isoleucine derivative with modifications: N-substituted'), "
               "('O=C(N[C@@H]([C@H](CC)C)C(=O)NCC(O)=O)[C@@H](N)CC(C)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N1[C@@H](CCC1)C(O)=O)[C@@H](NC(=O)[C@@H](NC(=O)[C@@H](NC(=O)[C@@H](NC(=O)[C@@H](NC(=O)[C@@H](N)C)CCCN=C(N)N)C(C)C)CC2=CC=C(O)C=C2)[C@H](CC)C)CC=3NC=NC3', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1NCCCCC(NC(=O)C(NC(=O)NC(C(=O)O)C(CC)C)C(C)C)C(NC(C=C1)C(C)C)=O', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C1OC(CC(=O)NC(C(=O)NC(C(=O)NC(CC(C)C)C(NC(C(NC(C(NC(C(NC1C(CC)C)=O)CC(C)C)=O)CC(=O)O)=O)C(C)C)=O)CC(C)C)CCC(=O)N)CCCCCCCCC(CC)C', "
               "'Isoleucine derivative with modifications: O-substituted, "
               "N-acylated'), "
               "('S(CCC1NC(=O)C(N(C(=O)C(NC(=O)C(C(C)C)NC(C(CCCCNC1=O)NC(=O)NC(C(=O)O)C(CC)C)=O)CCC2=CC=CC=C2)C)CCC3=CC=CC=C3)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N[C@@H](CC(O)=O)C(O)=O)[C@@H](NC(=O)[C@@H](N)CC=1NC=NC1)[C@H](CC)C', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(N[C@@H]([C@H](CC)C)C(O)=O)[C@@H](NC(=O)CN)CC=1NC=NC1', "
               "'Isoleucine derivative with modifications: N-acylated'), "
               "('O=C(O)[C@H](N(C(=O)[C@@H](NC(=O)C)[C@@H](CC)C)C)CC1=CC=C(O)C=C1', "
               "'Isoleucine derivative with modifications: N-acylated')]\n"
               'False negatives: '
               "[('S(=O)(=O)(NC(=O)[C@@H](N)[C@H](CC)C)CC(=O)N[C@]1(C(=O)O)[C@H]2[C@H](C(C(=O)N)=CN(C2)C)C[C@@H]1OC(=O)[C@@H](N)[C@H](C3=CC=CC=C3)C', "
               "'No isoleucine core structure found'), "
               "('O=C(N([C@H](C(=O)N[C@H](C(=O)N([C@H](C(=O)NCC(=O)N)[C@@H](CC)C)C)[C@@H](CC)C)C(C)C)C)[C@@H](N(C(=O)[C@@H](CCCCC#C)C)C)C(C)C', "
               "'Appears to be a peptide containing isoleucine rather than an "
               "isoleucine derivative'), "
               "('CCC(C)C(C(=O)OC1=CC2=C(C=C1)C3=C(CCC3)C(=O)O2)NS(=O)(=O)C4=CC=C(C=C4)C', "
               "'No isoleucine core structure found')]",
    'attempt': 1,
    'success': True,
    'best': True,
    'error': '',
    'stdout': None,
    'num_true_positives': 6,
    'num_false_positives': 100,
    'num_true_negatives': 6331,
    'num_false_negatives': 1,
    'num_negatives': None,
    'precision': 0.05660377358490566,
    'recall': 0.8571428571428571,
    'f1': 0.10619469026548672,
    'accuracy': 0.9843118981050015}


"""
Classifies: CHEBI:133558 hydroperoxyoctadecatrienoate
"""
from rdkit import Chem
from rdkit.Chem import AllChem
from rdkit.Chem import Descriptors
from rdkit.Chem import rdMolDescriptors

def is_hydroperoxyoctadecatrienoate(smiles: str):
    """
    Determines if a molecule is a hydroperoxyoctadecatrienoate (An octadecanoid anion that is octadecatrienoate
    containing a hydroperoxy substituent attached to its carbon chain).

    Args:
        smiles (str): SMILES string of the molecule

    Returns:
        bool: True if molecule is a hydroperoxyoctadecatrienoate, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return False, "Invalid SMILES string"

    # Check for the presence of 18 carbon atoms
    if mol.GetNumAtoms() != 18:
        return False, "Not an octadecanoid"

    # Check for the presence of a carboxylate group (-COO-)
    carboxylate_found = False
    for atom in mol.GetAtoms():
        if atom.GetSymbol() == 'O' and atom.GetFormalCharge() == -1:
            for neighbor in atom.GetNeighbors():
                if neighbor.GetSymbol() == 'C' and neighbor.GetDegree() == 3:
                    carboxylate_found = True
                    break
    if not carboxylate_found:
        return False, "No carboxylate group found"

    # Check for the presence of a hydroperoxy group (-OOH)
    hydroperoxy_found = False
    for atom in mol.GetAtoms():
        if atom.GetSymbol() == 'O' and atom.GetDegree() == 2:
            neighbors = [neighbor.GetSymbol() for neighbor in atom.GetNeighbors()]
            if 'O' in neighbors and 'C' in neighbors:
                hydroperoxy_found = True
                break
    if not hydroperoxy_found:
        return False, "No hydroperoxy group found"

    # Check for the presence of three double bonds
    double_bonds = Descriptors.Descriptors.BondCountDescriptors.NumAromaticRings(mol)
    if double_bonds != 3:
        return False, "Not an octadecatrienoate"

    return True, "Molecule is a hydroperoxyoctadecatrienoate"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:133558',
                          'name': 'hydroperoxyoctadecatrienoate',
                          'definition': 'An octadecanoid anion that is '
                                        'octadecatrienoate containing a '
                                        'hydroperoxy substituent attached to '
                                        'its carbon chain.',
                          'parents': [   'CHEBI:131860',
                                         'CHEBI:134019',
                                         'CHEBI:57560']},
    'config': {   'llm_model_name': 'claude-3-sonnet',
                  'f1_threshold': 0.8,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': None,
    'attempt': 0,
    'success': False,
    'best': True,
    'error': "module 'rdkit.Chem.Descriptors' has no attribute 'Descriptors'",
    'stdout': '',
    'num_true_positives': 0,
    'num_false_positives': 0,
    'num_true_negatives': 0,
    'num_false_negatives': 0,
    'num_negatives': None,
    'precision': 0.0,
    'recall': 0.0,
    'f1': 0.0,
    'accuracy': None}


"""
Classifies: CHEBI:24983 ketoxime
"""
from rdkit import Chem
from rdkit.Chem import AllChem
from rdkit.Chem import rdDecomposition

def is_ketoxime(smiles: str):
    """
    Determines if a molecule contains a ketoxime group (R2C=NOH where R =/= H).

    Args:
        smiles (str): SMILES string of the molecule

    Returns:
        bool: True if molecule contains ketoxime, False otherwise
        str: Reason for classification
    """
    # Parse SMILES
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return None, "Invalid SMILES string"

    # SMARTS pattern for ketoxime: [C]([!H])=N[OH]
    # Matches carbon with non-H substituent connected to N-OH
    ketoxime_pattern = Chem.MolFromSmarts('[C]([!H])=N[OH]')
    
    # Find matches
    matches = mol.GetSubstructMatches(ketoxime_pattern)
    
    if not matches:
        return False, "No ketoxime group found"
        
    # For each match, verify it's a ketoxime by checking:
    # 1. The carbon has exactly 2 non-H substituents (ketone requirement)
    # 2. The nitrogen is connected to exactly one OH and one C
    for match in matches:
        c_idx = match[0]  # Carbon atom index
        n_idx = match[1]  # Nitrogen atom index
        o_idx = match[2]  # Oxygen atom index
        
        c_atom = mol.GetAtomWithIdx(c_idx)
        n_atom = mol.GetAtomWithIdx(n_idx)
        o_atom = mol.GetAtomWithIdx(o_idx)
        
        # Check carbon valence (should have 3 bonds total - 2 substituents + 1 to N)
        if c_atom.GetDegree() != 3:
            continue
            
        # Check nitrogen valence (should have 2 bonds - 1 to C and 1 to O)
        if n_atom.GetDegree() != 2:
            continue
            
        # Check oxygen (should have 1 bond to N)
        if o_atom.GetDegree() != 1:
            continue
            
        # At this point we've confirmed a valid ketoxime group
        return True, "Contains ketoxime group (R2C=NOH)"
        
    return False, "No valid ketoxime group found"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:24983',
                          'name': 'ketoxime',
                          'definition': 'Oximes of ketones R2C=NOH (where R '
                                        '=/= H).',
                          'parents': ['CHEBI:25750']},
    'config': {   'llm_model_name': 'lbl/claude-sonnet',
                  'f1_threshold': 0.8,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': None,
    'attempt': 0,
    'success': False,
    'best': True,
    'error': "cannot import name 'rdDecomposition' from 'rdkit.Chem' "
             '(/Users/cjm/Library/Caches/pypoetry/virtualenvs/c3p-93U7KWO_-py3.11/lib/python3.11/site-packages/rdkit/Chem/__init__.py)',
    'stdout': '',
    'num_true_positives': 0,
    'num_false_positives': 0,
    'num_true_negatives': 0,
    'num_false_negatives': 0,
    'num_negatives': None,
    'precision': 0.0,
    'recall': 0.0,
    'f1': 0.0,
    'accuracy': None}


"""
Classifies: CHEBI:33497 transition element molecular entity
"""
from rdkit import Chem

# List of atomic numbers for transition elements
transition_elements = [21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103]

def is_transition_element_molecular_entity(smiles: str):
    """
    Determines if a molecular entity contains one or more atoms of a transition element.

    Args:
        smiles (str): SMILES string of the molecule

    Returns:
        bool: True if the molecule contains a transition element, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return False, "Invalid SMILES string"

    atoms = mol.GetAtoms()
    for atom in atoms:
        atomic_number = atom.GetAtomicNum()
        if atomic_number in transition_elements:
            element_symbol = atom.GetSymbol()
            return True, f"Molecule contains the transition element {element_symbol} (atomic number {atomic_number})"

    return False, "No transition elements found in the molecule"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:33497',
                          'name': 'transition element molecular entity',
                          'definition': 'A molecular entity containing one or '
                                        'more atoms of a transition element.',
                          'parents': ['CHEBI:23367']},
    'config': {   'llm_model_name': 'claude-3-sonnet',
                  'f1_threshold': 0.0,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': 'Attempt failed: unterminated string literal (detected at line '
               '1) (<string>, line 1)',
    'attempt': 2,
    'success': True,
    'best': True,
    'error': '',
    'stdout': None,
    'num_true_positives': 72,
    'num_false_positives': 100,
    'num_true_negatives': 44649,
    'num_false_negatives': 4,
    'num_negatives': None,
    'precision': 0.4186046511627907,
    'recall': 0.9473684210526315,
    'f1': 0.5806451612903226,
    'accuracy': 0.9976798661461238}


"""
Classifies: CHEBI:23628 deoxyhexose
"""
from rdkit import Chem
from rdkit.Chem import AllChem
from rdkit.Chem import rdMolDescriptors

def is_deoxyhexose(smiles: str):
    """
    Determines if a molecule is a deoxyhexose (C6 deoxy sugar with at least one OH replaced by H).
    
    Args:
        smiles (str): SMILES string of the molecule
        
    Returns:
        bool: True if molecule is a deoxyhexose, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return None, "Invalid SMILES string"
        
    # Check if molecule has exactly 6 carbons
    carbon_count = sum(1 for atom in mol.GetAtoms() if atom.GetSymbol() == 'C')
    if carbon_count != 6:
        return False, f"Not a C6 sugar - has {carbon_count} carbons"

    # Count oxygen atoms
    oxygen_count = sum(1 for atom in mol.GetAtoms() if atom.GetSymbol() == 'O')
    
    # Regular hexose would have 6 oxygens (5 OH groups + 1 ring/carbonyl O)
    # Deoxyhexose should have fewer oxygens due to H replacement
    if oxygen_count >= 6:
        return False, "Not deoxy - has all hydroxyl groups"
    
    # Check for presence of at least one OH group
    patt = Chem.MolFromSmarts('[OH]')
    if not mol.HasSubstructMatch(patt):
        return False, "No hydroxyl groups found"
        
    # Check for presence of either a ring oxygen or carbonyl group 
    # (characteristic of sugars)
    ring_o = Chem.MolFromSmarts('[O;R]')  # Ring oxygen
    carbonyl = Chem.MolFromSmarts('[C]=O') # Carbonyl
    
    if not (mol.HasSubstructMatch(ring_o) or mol.HasSubstructMatch(carbonyl)):
        return False, "No ring oxygen or carbonyl group found"

    # Calculate number of deoxy positions (missing OH groups)
    deoxy_count = 6 - oxygen_count
    
    return True, f"Deoxyhexose with {deoxy_count} deoxy position(s)"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:23628',
                          'name': 'deoxyhexose',
                          'definition': 'Any C6 deoxy sugar having at least '
                                        'one hydroxy group replaced by '
                                        'hydrogen.',
                          'parents': ['CHEBI:23639', 'CHEBI:33917']},
    'config': {   'llm_model_name': 'lbl/claude-sonnet',
                  'f1_threshold': 0.0,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': None,
    'attempt': 0,
    'success': True,
    'best': True,
    'error': '',
    'stdout': None,
    'num_true_positives': 5,
    'num_false_positives': 100,
    'num_true_negatives': 14249,
    'num_false_negatives': 0,
    'num_negatives': None,
    'precision': 0.047619047619047616,
    'recall': 1.0,
    'f1': 0.0909090909090909,
    'accuracy': 0.9930333008220705}


"""
Classifies: CHEBI:197528 fatty alcohol 23:0
"""
from rdkit import Chem
from rdkit.Chem import AllChem
from rdkit.Chem import Descriptors

def is_fatty_alcohol_23_0(smiles: str):
    """
    Determines if a molecule is a fatty alcohol 23:0 (contains 23 carbon atoms and one hydroxyl group).

    Args:
        smiles (str): SMILES string of the molecule

    Returns:
        bool: True if the molecule is a fatty alcohol 23:0, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return False, "Invalid SMILES string"

    # Check if the molecule has exactly 23 carbon atoms
    num_carbon_atoms = sum(1 for atom in mol.GetAtoms() if atom.GetSymbol() == 'C')
    if num_carbon_atoms != 23:
        return False, f"Molecule does not contain exactly 23 carbon atoms (found {num_carbon_atoms})"

    # Check if the molecule has exactly one hydroxyl group
    num_hydroxyl_groups = sum(1 for atom in mol.GetAtoms() if atom.GetSymbol() == 'O' and
                               atom.GetTotalNumHs() == 1)
    if num_hydroxyl_groups != 1:
        return False, f"Molecule does not contain exactly one hydroxyl group (found {num_hydroxyl_groups})"

    return True, "Molecule is a fatty alcohol 23:0"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:197528',
                          'name': 'fatty alcohol 23:0',
                          'definition': 'Any fatty alcohol containing 23 '
                                        'carbons.',
                          'parents': ['CHEBI:197504']},
    'config': {   'llm_model_name': 'claude-3-sonnet',
                  'f1_threshold': 0.8,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': None,
    'attempt': 0,
    'success': True,
    'best': True,
    'error': '',
    'stdout': None,
    'num_true_positives': 1,
    'num_false_positives': 100,
    'num_true_negatives': 7680,
    'num_false_negatives': 0,
    'num_negatives': None,
    'precision': 0.009900990099009901,
    'recall': 1.0,
    'f1': 0.0196078431372549,
    'accuracy': 0.9871481814676777}


"""
Classifies: CHEBI:22492 amino aldehyde
"""
from rdkit import Chem
from rdkit.Chem import AllChem

def is_amino_aldehyde(smiles: str):
    """
    Determines if a molecule is an amino aldehyde (aldehyde with an amino group).

    Args:
        smiles (str): SMILES string of the molecule

    Returns:
        bool: True if molecule is an amino aldehyde, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return False, "Invalid SMILES string"

    # Check for aldehyde group
    has_aldehyde = any(atom.GetHybridization() == Chem.HybridizationType.SP2 and
                       atom.GetTotalNumHs() == 0 and
                       sum(n.GetTotalNumHs(True) for n in atom.GetNeighbors()) == 1
                       for atom in mol.GetAtoms())

    if not has_aldehyde:
        return False, "No aldehyde group found"

    # Check for amino group
    has_amino = any(atom.GetSymbol() == 'N' and
                    atom.GetTotalNumHs() == 2 and
                    sum(n.GetTotalNumHs(True) for n in atom.GetNeighbors()) == 3
                    for atom in mol.GetAtoms())

    if not has_amino:
        return False, "No amino group found"

    return True, "Molecule is an amino aldehyde"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:22492',
                          'name': 'amino aldehyde',
                          'definition': 'Any aldehyde which contains an amino '
                                        'group.',
                          'parents': ['CHEBI:17478']},
    'config': {   'llm_model_name': 'claude-3-sonnet',
                  'f1_threshold': 0.0,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': None,
    'attempt': 0,
    'success': True,
    'best': True,
    'error': '',
    'stdout': None,
    'num_true_positives': 0,
    'num_false_positives': 100,
    'num_true_negatives': 145789,
    'num_false_negatives': 1,
    'num_negatives': None,
    'precision': 0.0,
    'recall': 0.0,
    'f1': 0,
    'accuracy': 0.9993076975803687}


"""
Classifies: CHEBI:27288 vinca alkaloid
"""
from rdkit import Chem
from rdkit.Chem import rdMolDescriptors
from rdkit.Chem.rdMolDescriptors import GetMorganFingerprint

def is_vinca_alkaloid(smiles: str):
    """
    Determines if a molecule is a vinca alkaloid.

    Args:
        smiles (str): SMILES string of the molecule

    Returns:
        bool: True if molecule is a vinca alkaloid, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return False, "Invalid SMILES string"

    # Check for indole and indoline rings
    indole_pattern = Chem.MolFromSmarts('c1ccc2c(c1)ncn2')
    indoline_pattern = Chem.MolFromSmarts('C1C=CN2C=CC=CC2=C1')

    if not mol.HasSubstructMatch(indole_pattern) or not mol.HasSubstructMatch(indoline_pattern):
        return False, "Missing indole or indoline ring"

    # Check for dimer structure
    morgan_fingerprint = GetMorganFingerprint(mol, 2, useChiralityTypes=True)
    if morgan_fingerprint.GetLength() < 150:
        return False, "Not a dimer structure"

    # Check for alkaloid
    num_basic_atoms = rdMolDescriptors.CalcNumBasicAtoms(mol)
    if num_basic_atoms < 1:
        return False, "Not an alkaloid"

    # Check for vinca plant origin or synthetic analog
    vinca_pattern = Chem.MolFromSmarts('C(=O)OC.C(=O)OC')
    if mol.HasSubstructMatch(vinca_pattern):
        return True, "Vinca alkaloid (natural or semi-synthetic)"
    else:
        return True, "Synthetic vinca alkaloid analog"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:27288',
                          'name': 'vinca alkaloid',
                          'definition': 'A group of indole-indoline dimers '
                                        'which are alkaloids obtained from the '
                                        'Vinca genus of plants, together with '
                                        'semi-synthetic and fully synthetic '
                                        'analogues.',
                          'parents': ['CHEBI:65323']},
    'config': {   'llm_model_name': 'claude-3-sonnet',
                  'f1_threshold': 0.0,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': None,
    'attempt': 0,
    'success': True,
    'best': True,
    'error': '',
    'stdout': None,
    'num_true_positives': 0,
    'num_false_positives': 0,
    'num_true_negatives': 183912,
    'num_false_negatives': 2,
    'num_negatives': None,
    'precision': 0.0,
    'recall': 0.0,
    'f1': 0.0,
    'accuracy': 0.9999891253520667}


"""
Classifies: CHEBI:32863 secondary amine
"""
from rdkit import Chem
from rdkit.Chem import Descriptors

def is_secondary_amine(smiles: str):
    """
    Determines if a molecule is a secondary amine.

    Args:
        smiles (str): SMILES string of the molecule

    Returns:
        bool: True if molecule is a secondary amine, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return False, "Invalid SMILES string"

    # Get the number of nitrogen atoms
    num_n_atoms = sum(1 for atom in mol.GetAtoms() if atom.GetAtomicNum() == 7)

    # Check if there is exactly one nitrogen atom
    if num_n_atoms != 1:
        return False, "Molecule does not contain exactly one nitrogen atom"

    # Get the nitrogen atom
    n_atom = next(atom for atom in mol.GetAtoms() if atom.GetAtomicNum() == 7)

    # Count the number of hydrogen atoms bonded to the nitrogen
    num_h_bonds = sum(1 for neighbor in n_atom.GetNeighbors() if neighbor.GetAtomicNum() == 1)

    # Check if the nitrogen atom has exactly one hydrogen bond
    if num_h_bonds != 1:
        return False, "Nitrogen atom does not have exactly one hydrogen bond"

    # Check if the nitrogen atom has exactly two non-hydrogen neighbors
    non_h_neighbors = [neighbor for neighbor in n_atom.GetNeighbors() if neighbor.GetAtomicNum() != 1]
    if len(non_h_neighbors) != 2:
        return False, "Nitrogen atom does not have exactly two non-hydrogen neighbors"

    return True, "Molecule is a secondary amine"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:32863',
                          'name': 'secondary amine',
                          'definition': 'A compound formally derived from '
                                        'ammonia by replacing two hydrogen '
                                        'atoms by hydrocarbyl groups.',
                          'parents': ['CHEBI:32952', 'CHEBI:50995']},
    'config': {   'llm_model_name': 'claude-3-sonnet',
                  'f1_threshold': 0.0,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': None,
    'attempt': 0,
    'success': True,
    'best': True,
    'error': '',
    'stdout': None,
    'num_true_positives': 0,
    'num_false_positives': 0,
    'num_true_negatives': 183883,
    'num_false_negatives': 5,
    'num_negatives': None,
    'precision': 0.0,
    'recall': 0.0,
    'f1': 0.0,
    'accuracy': 0.9999728095362395}


"""
Classifies: CHEBI:25448 myo-inositol phosphate
"""
from rdkit import Chem
from rdkit.Chem import AllChem

def is_myo_inositol_phosphate(smiles: str):
    """
    Determines if a molecule is a myo-inositol phosphate.
    
    Args:
        smiles (str): SMILES string of the molecule
        
    Returns:
        bool: True if molecule is a myo-inositol phosphate, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return False, "Invalid SMILES string"

    # Check for 6-membered ring
    rings = mol.GetRingInfo()
    if not any(len(ring) == 6 for ring in rings.AtomRings()):
        return False, "No 6-membered ring found"

    # Get the 6-membered ring
    ring = None
    for r in rings.AtomRings():
        if len(r) == 6:
            ring = r
            break

    # Check ring atoms are all carbon
    ring_atoms = [mol.GetAtomWithIdx(i) for i in ring]
    if not all(atom.GetSymbol() == 'C' for atom in ring_atoms):
        return False, "Ring must be composed of carbon atoms"

    # Check for at least one phosphate group
    phosphate_count = 0
    for atom in mol.GetAtoms():
        if atom.GetSymbol() == 'P':
            # Check if it's a phosphate group (P with 4 oxygen neighbors)
            oxygen_neighbors = sum(1 for n in atom.GetNeighbors() if n.GetSymbol() == 'O')
            if oxygen_neighbors == 4:
                phosphate_count += 1

    if phosphate_count == 0:
        return False, "No phosphate groups found"

    # Check for myo-inositol configuration
    # In myo-inositol, all hydroxyl groups are equatorial except one axial hydroxyl
    # This is represented in the SMILES by specific stereochemistry pattern
    
    # Get all substituents on the ring
    substituents = []
    for atom_idx in ring:
        atom = mol.GetAtomWithIdx(atom_idx)
        for neighbor in atom.GetNeighbors():
            if neighbor.GetIdx() not in ring:
                if neighbor.GetSymbol() == 'O':
                    substituents.append(neighbor)

    # Check if we have the correct number of substituents (should be 6)
    if len(substituents) != 6:
        return False, "Incorrect number of substituents on the ring"

    # For a valid myo-inositol phosphate, we need:
    # 1. At least one phosphate group
    # 2. The remaining positions should be hydroxyl groups
    # 3. Correct stereochemistry (though this is complex to verify completely)

    return True, f"Myo-inositol phosphate with {phosphate_count} phosphate group(s)"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:25448',
                          'name': 'myo-inositol phosphate',
                          'definition': 'An inositol phosphate in which the '
                                        'inositol component has '
                                        'myo-configuration.',
                          'parents': ['CHEBI:24846']},
    'config': {   'llm_model_name': 'lbl/claude-sonnet',
                  'f1_threshold': 0.0,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': None,
    'attempt': 0,
    'success': True,
    'best': True,
    'error': '',
    'stdout': None,
    'num_true_positives': 4,
    'num_false_positives': 100,
    'num_true_negatives': 24559,
    'num_false_negatives': 0,
    'num_negatives': None,
    'precision': 0.038461538461538464,
    'recall': 1.0,
    'f1': 0.07407407407407407,
    'accuracy': 0.9959453432266958}


"""
Classifies: CHEBI:133492 polyunsaturated dicarboxylic acid dianion
"""
from rdkit import Chem
from rdkit.Chem import AllChem
from rdkit.Chem import Descriptors
from rdkit.Chem import rdMolDescriptors

def is_polyunsaturated_dicarboxylic_acid_dianion(smiles: str):
    """
    Determines if a molecule is a polyunsaturated dicarboxylic acid dianion.
    
    Args:
        smiles (str): SMILES string of the molecule
        
    Returns:
        bool: True if molecule is a polyunsaturated dicarboxylic acid dianion, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return None, "Invalid SMILES string"

    # Check for presence of exactly 2 carboxylate groups (-COO-)
    carboxylate_pattern = Chem.MolFromSmarts('[C](=[O])[O-]')
    matches = mol.GetSubstructMatches(carboxylate_pattern)
    
    if len(matches) != 2:
        return False, f"Found {len(matches)} carboxylate groups, need exactly 2"

    # Count double bonds excluding those in carboxylate groups
    double_bond_pattern = Chem.MolFromSmarts('C=C')
    double_bond_matches = len(mol.GetSubstructMatches(double_bond_pattern))
    
    # Get total formal charge
    total_charge = sum(atom.GetFormalCharge() for atom in mol.GetAtoms())
    
    if total_charge != -2:
        return False, f"Total charge is {total_charge}, should be -2"
        
    # For polyunsaturated, need at least 2 units of unsaturation 
    # (double bonds or rings) excluding the carboxylate groups
    if double_bond_matches < 2:
        return False, f"Found only {double_bond_matches} C=C double bonds, need at least 2 for polyunsaturation"
        
    # If we get here, molecule meets all criteria
    return True, f"Contains 2 carboxylate groups, {double_bond_matches} C=C double bonds, and -2 total charge"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:133492',
                          'name': 'polyunsaturated dicarboxylic acid dianion',
                          'definition': 'A dicarboxylic acid dianion having 2 '
                                        'or more units of unsaturation.',
                          'parents': ['CHEBI:28965']},
    'config': {   'llm_model_name': 'lbl/claude-sonnet',
                  'f1_threshold': 0.8,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': None,
    'attempt': 0,
    'success': True,
    'best': True,
    'error': '',
    'stdout': None,
    'num_true_positives': 2,
    'num_false_positives': 88,
    'num_true_negatives': 183821,
    'num_false_negatives': 0,
    'num_negatives': None,
    'precision': 0.022222222222222223,
    'recall': 1.0,
    'f1': 0.04347826086956522,
    'accuracy': 0.9995215076857829}


"""
Classifies: CHEBI:24026 fatty alcohol
"""
from rdkit import Chem
from rdkit.Chem import AllChem
from rdkit.Chem import rdMolDescriptors

def is_fatty_alcohol(smiles: str):
    """
    Determines if a molecule is a fatty alcohol (aliphatic alcohol with 3+ carbon chain).
    
    Args:
        smiles (str): SMILES string of the molecule
        
    Returns:
        bool: True if molecule is a fatty alcohol, False otherwise
        str: Reason for classification
    """
    # Handle invalid SMILES and wildcards
    if '*' in smiles:
        return True, "Generic fatty alcohol notation"
        
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return None, "Invalid SMILES string"
        
    # Check for presence of OH group
    if not any(atom.GetSymbol() == 'O' for atom in mol.GetAtoms()):
        return False, "No oxygen atoms found"
        
    # Find OH groups
    oh_pattern = Chem.MolFromSmarts('[OH]')
    if not mol.HasSubstructMatch(oh_pattern):
        return False, "No hydroxyl groups found"
        
    # Count carbons
    carbon_count = sum(1 for atom in mol.GetAtoms() if atom.GetSymbol() == 'C')
    if carbon_count < 3:
        return False, f"Insufficient carbon atoms ({carbon_count})"
    
    # Check if aliphatic
    ring_info = mol.GetRingInfo()
    if ring_info.NumRings() > 0:
        # Allow aliphatic rings but not aromatic
        aromatic_atoms = {a.GetIdx() for a in mol.GetAromaticAtoms()}
        if len(aromatic_atoms) > 0:
            return False, "Contains aromatic rings"
            
    # Find longest carbon chain
    frags = rdMolDescriptors.CalcMolFormula(mol).split('.')
    if len(frags) > 1:
        return False, "Multiple disconnected fragments"
        
    return True, f"Fatty alcohol with {carbon_count} carbons"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:24026',
                          'name': 'fatty alcohol',
                          'definition': 'An aliphatic alcohol consisting of a '
                                        'chain of 3 to greater than 27 carbon '
                                        'atoms. Fatty alcohols may be '
                                        'saturated or unsaturated and may be '
                                        'branched or unbranched.',
                          'parents': ['CHEBI:30879', 'CHEBI:61697']},
    'config': {   'llm_model_name': 'lbl/claude-sonnet',
                  'f1_threshold': 0.0,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': "Attempt failed: module 'rdkit.Chem.AllChem' has no attribute "
               "'ReduceMolecule'",
    'attempt': 1,
    'success': True,
    'best': True,
    'error': '',
    'stdout': None,
    'num_true_positives': 54,
    'num_false_positives': 100,
    'num_true_negatives': 246,
    'num_false_negatives': 4,
    'num_negatives': None,
    'precision': 0.35064935064935066,
    'recall': 0.9310344827586207,
    'f1': 0.5094339622641509,
    'accuracy': 0.7425742574257426}


"""
Classifies: CHEBI:26935 tetraterpenoid
"""
from rdkit import Chem
from rdkit.Chem import Descriptors

def is_tetraterpenoid(smiles: str):
    """
    Determines if a molecule is a tetraterpenoid.

    Tetraterpenoids are defined as any terpenoid derived from a tetraterpene (C40 skeleton),
    which may have undergone rearrangements or modifications (e.g., removal of methyl groups).

    Args:
        smiles (str): SMILES string of the molecule

    Returns:
        bool: True if molecule is a tetraterpenoid, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return False, "Invalid SMILES string"

    # Calculate the number of carbon atoms
    num_carbon = sum(1 for atom in mol.GetAtoms() if atom.GetSymbol() == 'C')

    # Check if the number of carbon atoms is around 40 (+/- 5)
    if not 35 <= num_carbon <= 45:
        return False, "Number of carbon atoms not around 40 (tetraterpenoid range)"

    # Check if the molecule contains any rings
    rings = mol.GetRingInfo().AtomRings()
    if not rings:
        return False, "No rings found (tetraterpenoids are expected to have rings)"

    # Check if the molecule has specific functional groups or structural features
    # Tetraterpenoids can have a wide variety of structures, so this check is optional
    # and may not be reliable for all cases

    # Example: Check for the presence of a conjugated double bond system
    num_double_bonds = sum(1 for bond in mol.GetBonds() if bond.GetBondType() == Chem.BondType.DOUBLE)
    num_conjugated_double_bonds = Descriptors.NumAromaticRings(mol)
    if num_double_bonds > 0 and num_conjugated_double_bonds > 0:
        return True, "Molecule contains conjugated double bond system (characteristic of tetraterpenoids)"
    else:
        return True, "Molecule classified as tetraterpenoid based on carbon count and ring presence"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:26935',
                          'name': 'tetraterpenoid',
                          'definition': 'Any terpenoid derived from a '
                                        'tetraterpene. The term includes '
                                        'compounds in which the C40 skeleton '
                                        'of the parent tetraterpene has been '
                                        'rearranged or modified by the removal '
                                        'of one or more skeletal atoms '
                                        '(generally methyl groups).',
                          'parents': ['CHEBI:26873']},
    'config': {   'llm_model_name': 'claude-3-sonnet',
                  'f1_threshold': 0.8,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': "Attempt failed: module 'rdkit.Chem.Descriptors' has no "
               "attribute 'ConjugatedPiElectronsDetector'",
    'attempt': 1,
    'success': True,
    'best': True,
    'error': '',
    'stdout': None,
    'num_true_positives': 16,
    'num_false_positives': 100,
    'num_true_negatives': 1671,
    'num_false_negatives': 9,
    'num_negatives': None,
    'precision': 0.13793103448275862,
    'recall': 0.64,
    'f1': 0.2269503546099291,
    'accuracy': 0.9393095768374164}


"""
Classifies: CHEBI:33247 organic group
"""
from rdkit import Chem

def is_organic_group(smiles: str):
    """
    Determines if a molecule is an organic group.
    Organic group is defined as 'Any substituent group or skeleton containing carbon.'

    Args:
        smiles (str): SMILES string of the molecule

    Returns:
        bool: True if molecule is an organic group, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return False, "Invalid SMILES string"

    # Check if the molecule contains carbon
    has_carbon = any(atom.GetSymbol() == 'C' for atom in mol.GetAtoms())

    if has_carbon:
        return True, "Molecule contains carbon"
    else:
        return False, "Molecule does not contain carbon"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:33247',
                          'name': 'organic group',
                          'definition': 'Any substituent group or skeleton '
                                        'containing carbon.',
                          'parents': ['CHEBI:24433']},
    'config': {   'llm_model_name': 'claude-3-sonnet',
                  'f1_threshold': 0.0,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': None,
    'attempt': 0,
    'success': True,
    'best': True,
    'error': '',
    'stdout': None,
    'num_true_positives': 166,
    'num_false_positives': 100,
    'num_true_negatives': 0,
    'num_false_negatives': 0,
    'num_negatives': None,
    'precision': 0.6240601503759399,
    'recall': 1.0,
    'f1': 0.7685185185185186,
    'accuracy': 0.6240601503759399}


"""
Classifies: CHEBI:33456 organoheteryl group
"""
from rdkit import Chem
from rdkit.Chem import AllChem
from rdkit.Chem import Descriptors
from rdkit.Chem import rdMolDescriptors

def is_organoheteryl_group(smiles: str):
    """
    Determines if a molecule is an organoheteryl group (a univalent group containing carbon with its free valence at an atom other than carbon).

    Args:
        smiles (str): SMILES string of the molecule

    Returns:
        bool: True if molecule is an organoheteryl group, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return False, "Invalid SMILES string"

    # Check for presence of a carbon atom
    has_carbon = any(atom.GetSymbol() == 'C' for atom in mol.GetAtoms())
    if not has_carbon:
        return False, "No carbon atoms found"

    # Check for the presence of an atom with a free valence
    for atom in mol.GetAtoms():
        if atom.GetNumRadicalElectrons() == 1:
            radicalSymbol = atom.GetSymbol()
            if radicalSymbol != 'C':
                return True, f"Organoheteryl group with free valence at {radicalSymbol}"

    return False, "No atom with a free valence found"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:33456',
                          'name': 'organoheteryl group',
                          'definition': 'A univalent group containing carbon '
                                        'which has its free valence at an atom '
                                        'other than carbon.',
                          'parents': ['CHEBI:51447']},
    'config': {   'llm_model_name': 'claude-3-sonnet',
                  'f1_threshold': 0.0,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': None,
    'attempt': 0,
    'success': True,
    'best': True,
    'error': '',
    'stdout': None,
    'num_true_positives': 0,
    'num_false_positives': 100,
    'num_true_negatives': 158002,
    'num_false_negatives': 10,
    'num_negatives': None,
    'precision': 0.0,
    'recall': 0.0,
    'f1': 0,
    'accuracy': 0.9993042906294273}


"""
Classifies: CHEBI:131864 docosanoid anion
"""
from rdkit import Chem
from rdkit.Chem import AllChem

def is_docosanoid_anion(smiles: str):
    """
    Determines if a molecule is a docosanoid anion.
    
    Args:
        smiles (str): SMILES string of the molecule
        
    Returns:
        bool: True if molecule is a docosanoid anion, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return None, "Invalid SMILES string"
        
    # Check for presence of carboxylate anion
    carboxylate_pattern = Chem.MolFromSmarts('C(=O)[O-]')
    if not mol.HasSubstructMatch(carboxylate_pattern):
        return False, "No carboxylate anion present"
        
    # Count carbons
    carbon_count = sum(1 for atom in mol.GetAtoms() if atom.GetSymbol() == 'C')
    if carbon_count != 22:
        return False, f"Not a C22 structure (found {carbon_count} carbons)"
        
    # Check for unsaturation (double bonds)
    double_bond_pattern = Chem.MolFromSmarts('C=C')
    double_bonds = len(mol.GetSubstructMatches(double_bond_pattern))
    if double_bonds < 2:
        return False, "Insufficient unsaturation (needs multiple double bonds)"
        
    # Count oxygen atoms (should have at least 2 - one from carboxylate)
    oxygen_count = sum(1 for atom in mol.GetAtoms() if atom.GetSymbol() == 'O')
    if oxygen_count < 2:
        return False, "Insufficient oxygen atoms"
        
    # Verify chain structure (should be largely aliphatic)
    aromatic_atoms = sum(1 for atom in mol.GetAtoms() if atom.GetIsAromatic())
    if aromatic_atoms > 0:
        return False, "Contains aromatic systems"
        
    return True, "Docosanoid anion with carboxylate group and unsaturated chain"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:131864',
                          'name': 'docosanoid anion',
                          'definition': 'A polyunsaturated fatty acid anion '
                                        'obtained by the deprotonation of the '
                                        'carboxy group of any docosanoid.',
                          'parents': ['CHEBI:57560']},
    'config': {   'llm_model_name': 'lbl/claude-sonnet',
                  'f1_threshold': 0.8,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': "Attempt failed: module 'rdkit.Chem.rdMolDescriptors' has no "
               "attribute 'CalcNumAliphaticDoubleBonds'",
    'attempt': 1,
    'success': True,
    'best': True,
    'error': '',
    'stdout': None,
    'num_true_positives': 6,
    'num_false_positives': 21,
    'num_true_negatives': 183820,
    'num_false_negatives': 3,
    'num_negatives': None,
    'precision': 0.2222222222222222,
    'recall': 0.6666666666666666,
    'f1': 0.3333333333333333,
    'accuracy': 0.9998694587979331}


"""
Classifies: CHEBI:131869 hydroxy monounsaturated fatty acid
"""
from rdkit import Chem
from rdkit.Chem import AllChem
from rdkit.Chem import Descriptors

def is_hydroxy_monounsaturated_fatty_acid(smiles: str):
    """
    Determines if a molecule is a hydroxy monounsaturated fatty acid.
    
    Args:
        smiles (str): SMILES string of the molecule
        
    Returns:
        bool: True if molecule is a hydroxy monounsaturated fatty acid, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return None, "Invalid SMILES string"

    # Check for carboxylic acid group
    carboxylic_pattern = Chem.MolFromSmarts('C(=O)[OH]')
    if not mol.HasSubstructMatch(carboxylic_pattern):
        return False, "No carboxylic acid group found"

    # Check for hydroxyl groups (excluding the one in carboxylic acid)
    hydroxyl_pattern = Chem.MolFromSmarts('[CX4][OH]')
    hydroxy_matches = mol.GetSubstructMatches(hydroxyl_pattern)
    if not hydroxy_matches:
        return False, "No hydroxyl groups found"

    # Check for double bonds
    double_bond_pattern = Chem.MolFromSmarts('C=C')
    double_bond_matches = mol.GetSubstructMatches(double_bond_pattern)
    
    if not double_bond_matches:
        return False, "No double bonds found"
    
    if len(double_bond_matches) > 1:
        return False, "More than one double bond found (not monounsaturated)"

    # Check if it's a fatty acid by verifying chain length (at least 4 carbons)
    carbon_count = sum(1 for atom in mol.GetAtoms() if atom.GetSymbol() == 'C')
    if carbon_count < 4:
        return False, "Chain too short to be a fatty acid"

    # Count number of hydroxyl groups
    num_hydroxy = len(hydroxy_matches)
    
    # Get stereochemistry of double bond if present
    double_bond = mol.GetBondBetweenAtoms(double_bond_matches[0][0], double_bond_matches[0][1])
    stereo = "E" if double_bond.GetStereo() == Chem.BondStereo.STEREOE else "Z" if double_bond.GetStereo() == Chem.BondStereo.STEREOZ else "unspecified"

    return True, f"Hydroxy monounsaturated fatty acid with {num_hydroxy} hydroxyl group(s) and {stereo} double bond"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:131869',
                          'name': 'hydroxy monounsaturated fatty acid',
                          'definition': 'Any monounsaturated fatty acid '
                                        'carrying one or more hydroxy '
                                        'substituents.',
                          'parents': ['CHEBI:24654', 'CHEBI:25413']},
    'config': {   'llm_model_name': 'lbl/claude-sonnet',
                  'f1_threshold': 0.8,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': None,
    'attempt': 0,
    'success': True,
    'best': True,
    'error': '',
    'stdout': None,
    'num_true_positives': 5,
    'num_false_positives': 100,
    'num_true_negatives': 6404,
    'num_false_negatives': 0,
    'num_negatives': None,
    'precision': 0.047619047619047616,
    'recall': 1.0,
    'f1': 0.0909090909090909,
    'accuracy': 0.9846366569365494}


"""
Classifies: CHEBI:23238 chromones
"""
from rdkit import Chem
from rdkit.Chem import AllChem
from rdkit.Chem import rdDecomposition

def is_chromones(smiles: str):
    """
    Determines if a molecule is a chromone (1,4-benzopyrone) or derivative.
    
    Args:
        smiles (str): SMILES string of the molecule
        
    Returns:
        bool: True if molecule is a chromone, False otherwise
        str: Reason for classification
    """
    mol = Chem.MolFromSmiles(smiles)
    if mol is None:
        return False, "Invalid SMILES string"
        
    # Check for basic chromone scaffold
    chromone_pattern = Chem.MolFromSmarts('[#6]1=CC(=O)c2ccccc2O1')
    if not mol.HasSubstructMatch(chromone_pattern):
        return False, "Does not contain chromone (1,4-benzopyrone) core structure"
        
    # Get matches of chromone pattern
    matches = mol.GetSubstructMatches(chromone_pattern)
    
    # Check that we have at least one match
    if len(matches) == 0:
        return False, "No chromone substructure found"
        
    # Get atoms in first match
    match_atoms = set(matches[0])
    
    # Check for substituents
    substituents = []
    for match in matches:
        for atom_idx in match:
            atom = mol.GetAtomWithIdx(atom_idx)
            for neighbor in atom.GetNeighbors():
                if neighbor.GetIdx() not in match_atoms:
                    substituents.append(neighbor.GetSymbol())
                    
    if len(substituents) > 0:
        return True, f"Substituted chromone with substituents: {', '.join(set(substituents))}"
    else:
        return True, "Unsubstituted chromone"


__metadata__ = {   'chemical_class': {   'id': 'CHEBI:23238',
                          'name': 'chromones',
                          'definition': 'A chromenone that consists of a '
                                        '1,4-benzopyrone skeleton and its '
                                        'substituted derivatives thereof.',
                          'parents': ['CHEBI:38445']},
    'config': {   'llm_model_name': 'lbl/claude-sonnet',
                  'f1_threshold': 0.0,
                  'max_attempts': 5,
                  'max_negative_to_test': None,
                  'max_positive_in_prompt': 50,
                  'max_negative_in_prompt': 20,
                  'max_instances_in_prompt': 100,
                  'test_proportion': 0.1},
    'message': None,
    'attempt': 0,
    'success': False,
    'best': True,
    'error': "cannot import name 'rdDecomposition' from 'rdkit.Chem' "
             '(/Users/cjm/Library/Caches/pypoetry/virtualenvs/c3p-93U7KWO_-py3.11/lib/python3.11/site-packages/rdkit/Chem/__init__.py)',
    'stdout': '',
    'num_true_positives': 0,
    'num_false_positives': 0,
    'num_true_negatives': 0,
    'num_false_negatives': 0,
    'num_negatives': None,
    'precision': 0.0,
    'recall': 0.0,
    'f1': 0.0,
    'accuracy': None}